#
#  CS Animation
#  A tool for creating computer science explanatory videos.
#  Copyright Patrick Huang 2021
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#

__all__ = [
    "I_CONST",
    "I_LIN",
    "I_SINE",
    "I_BOUNCE",
    "T_CUT",
    "T_FADE",
    "T_FADEIO",
]

I_CONST: int = 0
I_LIN: int = 1
I_SINE: int = 2
I_BOUNCE: int = 3
T_CUT: int = 4
T_FADE: int = 5
T_FADEIO: int = 6
